import{p as h,s as d,X as n,Y as l,P as g,t as c,aL as f}from"./index-BHT8kH88.js";const x=h({height:[Number,String],maxHeight:[Number,String],maxWidth:[Number,String],minHeight:[Number,String],minWidth:[Number,String],width:[Number,String]},"dimension");function b(t){return{dimensionStyles:d(()=>{const i={},e=n(t.height),s=n(t.maxHeight),o=n(t.maxWidth),a=n(t.minHeight),m=n(t.minWidth),r=n(t.width);return e!=null&&(i.height=e),s!=null&&(i.maxHeight=s),o!=null&&(i.maxWidth=o),a!=null&&(i.minHeight=a),m!=null&&(i.minWidth=m),r!=null&&(i.width=r),i})}}function y(){const t=l(!1);return g(()=>{window.requestAnimationFrame(()=>{t.value=!0})}),{ssrBootStyles:c(()=>t.value?void 0:{transition:"none !important"}),isBooted:f(t)}}const H=h({tag:{type:[String,Object,Function],default:"div"}},"tag");export{x as a,y as b,H as m,b as u};
