import{p as r,m as c,g as m,u as i,a as u,c as t,n as _,b as d,d as p,e as v,r as f,o as y,w as b}from"./index-BHT8kH88.js";import{m as k,a as B,u as V,b as g}from"./tag-C3AsqX5u.js";const C=r({scrollable:Boolean,...c(),...B(),...k({tag:"main"})},"VMain"),S=m()({name:"VMain",props:C(),setup(e,o){let{slots:a}=o;const{dimensionStyles:s}=V(e),{mainStyles:n}=i(),{ssrBootStyles:l}=g();return u(()=>t(e.tag,{class:d(["v-main",{"v-main--scrollable":e.scrollable},e.class]),style:_([n.value,l.value,s.value,e.style])},{default:()=>[e.scrollable?p("div",{class:"v-main__scroller"},[a.default?.()]):a.default?.()]})),{}}}),P={__name:"default",setup(e){return(o,a)=>{const s=f("router-view");return y(),v(S,null,{default:b(()=>[t(s)]),_:1})}}};export{P as default};
